package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.BusinessUser;

/**
 * 出差人员信息Mapper接口
 * 
 * @author ruoyi
 * @date 2025-06-23
 */
public interface BusinessUserMapper 
{
    /**
     * 查询出差人员信息
     * 
     * @param id 出差人员信息主键
     * @return 出差人员信息
     */
    public BusinessUser selectBusinessUserById(Long id);

    /**
     * 查询出差人员信息列表
     * 
     * @param businessUser 出差人员信息
     * @return 出差人员信息集合
     */
    public List<BusinessUser> selectBusinessUserList(BusinessUser businessUser);

    /**
     * 新增出差人员信息
     * 
     * @param businessUser 出差人员信息
     * @return 结果
     */
    public int insertBusinessUser(BusinessUser businessUser);

    /**
     * 修改出差人员信息
     * 
     * @param businessUser 出差人员信息
     * @return 结果
     */
    public int updateBusinessUser(BusinessUser businessUser);

    /**
     * 删除出差人员信息
     * 
     * @param id 出差人员信息主键
     * @return 结果
     */
    public int deleteBusinessUserById(Long id);

    /**
     * 批量删除出差人员信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusinessUserByIds(Long[] ids);

    void deleteBusinessUserByBusinessId(Long id);
}
